@@ -1,9 +1,11 @@
 #!/usr/bin/env python3
 
 from typing import Text
+
+import click
+
 from .main import process
 from .version import __version__
-import click
 
 """bagit-create command line tool."""
 
@@ -14,11 +16,16 @@ import click
     "--recid",
     help="Record ID of the resource the upstream digital repository. Required by every pipeline but local.",
 )
+@click.option(
+    "-u",
+    "--url",
+    help="Provide an URL for the Record. Must be from the supported sources.",
+    type=Text
+)
 @click.option(
     "-s",
     "--source",
     help="Select source pipeline from the supported ones.",
-    required=True,
     type=click.Choice(
         ["cds", "ilcdoc", "cod", "zenodo", "inveniordm", "indico", "local", "ilcagenda"],
         case_sensitive=False,
@@ -35,7 +42,7 @@ import click
     "-a",
     "--alternate-uri",
     help="""
-         Use alternative uri instead of https for fetch.txt (e.g. root endpoints 
+         Use alternative uri instead of https for fetch.txt (e.g. root endpoints
          for CERN Open Data instead of http).""",
     default=False,
     is_flag=True,
@@ -78,7 +85,7 @@ import click
     "--target",
     "-t",
     help="""
-    Output folder for the generated SIP. By default uses the same folder 
+    Output folder for the generated SIP. By default uses the same folder
     the tool is being executed from.""",
     type=Text,
     default=None,
@@ -105,7 +112,7 @@ import click
     "--source-base-path",
     "-sbp",
     help="""
-    [Local source ONLY] Specify a part of the path as 
+    [Local source ONLY] Specify a part of the path as
     relevant for extracting an hierachy.""",
     type=Text,
     default=None,
@@ -160,7 +167,8 @@ def cli(
     bd_ssh_host,
     cert,
     invcookie,
-    skipssl
+    skipssl,
+    url
 ):
 
     # Select the desired log level (default is 2, warning)
@@ -187,7 +195,8 @@ def cli(
         bd_ssh_host,
         cert,
         invcookie,
-        skipssl
+        skipssl,
+        url
     )
     print(f"Job result: {result}")
 
