@@ -1,17 +1,12 @@
-from fs import base
-from .pipelines import invenio_v1
-from .pipelines import invenio_v3
-from .pipelines import opendata
-from .pipelines import indico
-from .pipelines import local
-from .pipelines import base
-from .pipelines.base import WrongInputException
-
 import logging
+import time
+
 import fs
 from fs import open_fs
+
+from .pipelines import base, indico, invenio_v1, invenio_v3, local, opendata
+from .pipelines.base import WrongInputException
 from .version import __version__
-import time
 
 my_fs = open_fs(".")
 
@@ -30,7 +25,8 @@ def process(
     timestamp=0,
     cert=None,
     invcookie=None,
-    skipssl=False
+    skipssl=False,
+    url=None,
 ):
     # Save timestamp
     timestamp = int(time.time())
@@ -38,6 +34,7 @@ def process(
     # Save parameters with which bagit-create was called
     params = {
         "recid": recid,
+        "url": url,
         "source": source,
         "loglevel": loglevel,
         "target": target,
@@ -54,6 +51,7 @@ def process(
     try:
         base.BasePipeline.check_parameters_input(
             recid,
+            url,
             source,
             source_path,
             author,
@@ -76,7 +74,7 @@ def process(
 
     ## Console Handler
     # create console handler logging to the shell
-    # what has been requested by the author (-v or -vv)
+    # what has been requested by the user (-v or -vv)
     ch_formatter = logging.Formatter("%(message)s")
     ch = logging.StreamHandler()
     ch.setLevel(loglevels[loglevel])
@@ -97,6 +95,11 @@ def process(
     log.debug(f"Set log level: {loglevels[loglevel]}")
     log.debug(f"Parametrs: {params}")
 
+    if url:
+        # If an URL is provided, parse it to get Source and Record ID
+        source, recid = base.BasePipeline.parse_url(url)
+        log.info(f"Got record {recid} from {source} from parsing URL")
+
     if dry_run:
         log.warning(
             """This will be a DRY RUN. A 'light' bag will be created, not downloading
@@ -107,11 +110,11 @@ def process(
         # Initialize the pipeline
         if source == "cds":
             pipeline = invenio_v1.InvenioV1Pipeline(
-                "https://cds.cern.ch/record/", cert_path=cert, recid=recid, 
+                "https://cds.cern.ch/record/", cert_path=cert, recid=recid,
                 invcookie=invcookie, skipssl=skipssl)
         elif source == "ilcdoc":
             pipeline = invenio_v1.InvenioV1Pipeline(
-                "http://ilcdoc.linearcollider.org/record/", cert_path=cert, 
+                "http://ilcdoc.linearcollider.org/record/", cert_path=cert,
                 recid=recid, invcookie=invcookie, skipssl=skipssl
             )
         elif source == "cod":
