@@ -1,20 +1,23 @@
-import requests
 import json
-import os
 import logging
-import time
+import os
 import re
-import fs
-from fs import open_fs
-from ..version import __version__
-import bagit
 import shutil
-from itertools import chain
-from zlib import adler32
+import time
 from datetime import date
-from pathlib import Path
+from itertools import chain
+from pathlib import Path, PurePosixPath
+from urllib.parse import unquote, urlparse
+from zlib import adler32
+
+import bagit
+import fs
+import requests
+from fs import open_fs
 from jsonschema import validate
 
+from ..version import __version__
+
 my_fs = open_fs("/")
 
 log = logging.getLogger("bic-basic-logger")
@@ -60,8 +63,8 @@ class BasePipeline:
         except Exception as err:
             log.error("sip.json validation failed with error", err)
 
-    def downloadRemoteFile(self, src, dest):
-        r = requests.get(src)
+    def downloadRemoteFile(self, src, dest, headers={}):
+        r = requests.get(src, headers=headers)
         with open(dest, "wb") as f:
             f.write(r.content)
         return True
@@ -226,8 +229,8 @@ class BasePipeline:
                 # If there is no local mode get the origin url
                 else:
                     param = file["origin"]["url"]
-            except:
-                raise Exception(f"Malformed files object")
+            except Exception:
+                raise Exception("Malformed files object")
             if type(param) is list:
                 param = param[0]
 
@@ -283,12 +286,12 @@ class BasePipeline:
     ):
         # Copy each file from the temp folder to the AIU folders
         for idx, file in enumerate(files):
-            if file["downloaded"] and file["metadata"] == False:
+            if file["downloaded"] and file["metadata"] is False:
                 filehash = self.compute_hash(f"{temp_relpath}/{file['filename']}")
                 aiufoldername = f"{base_path}/data/{recid}{delimiter_str}{filehash}"
                 try:
                     os.mkdir(aiufoldername)
-                except:
+                except Exception:
                     log.warning(
                         "Trying to create an already existing AIU. Duplicate files or"
                         " colliding checksums?"
@@ -301,14 +304,13 @@ class BasePipeline:
                         f"{temp_relpath}/{file['filename']}",
                         f"{base_path}/data/{recid}{delimiter_str}{filehash}/{file['filename']}",
                     )
-                except:
+                except Exception:
                     log.warning(f"{temp_relpath}/{file['filename']} already exists")
 
-            if file["downloaded"] == False and file["metadata"] == False:
+            if file["downloaded"] is False and file["metadata"] is False:
                 if "checksum" in file:
                     p = re.compile(r"([A-z0-9]*):([A-z0-9]*)")
                     m = p.match(file["checksum"])
-                    alg = m.groups()[0].lower()
                     matched_checksum = m.groups()[1]
                     files[idx][
                         "localpath"
@@ -355,7 +357,7 @@ class BasePipeline:
             },
             "metadata": False,
             "downloaded": True,
-            "bagpath": f"data/meta/bagitcreate.log",
+            "bagpath": "data/meta/bagitcreate.log",
         }
 
         files.append(bic_log_file_entry)
@@ -367,7 +369,7 @@ class BasePipeline:
             },
             "metadata": False,
             "downloaded": True,
-            "bagpath": f"data/meta/sip.json",
+            "bagpath": "data/meta/sip.json",
         }
 
         files.append(bic_meta_file_entry)
@@ -387,7 +389,7 @@ class BasePipeline:
         except bagit.BagValidationError as err:
             log.error(f"Bag validation failed: {err}")
         if valid:
-            log.info(f"Bag successfully validated")
+            log.info("Bag successfully validated")
         log.info("--\n")
         return valid
 
@@ -405,9 +407,47 @@ class BasePipeline:
         # move folder to the target location
         fs.move.move_fs(base_path, new_path)
 
+    def parse_url(url):
+        """
+        Parses URLs with the pattern
+        <HOSTNAME>/record/<RECORD_ID>
+        (CDS, Zenodo, Open Data)
+        """
+        o = urlparse(url)
+        if o.hostname == "cds.cern.ch":
+            source = "cds"
+        elif o.hostname == "opendata.cern.ch":
+            source = "cod"
+        elif o.hostname == "zenodo.org":
+            source = "zenodo"
+        else:
+            raise WrongInputException(
+                "Unable to parse the given URL. Try manually passing the source and the record ID."
+            )
+
+        path_parts = PurePosixPath(
+            unquote(
+                urlparse(
+                    url
+                ).path
+            )
+        ).parts
+
+        # Ensures the path is in the form /record/<RECORD_ID>
+        if path_parts[0] == '/' and path_parts[1] == 'record':
+            # The ID is the second part of the path
+            recid = path_parts[2]
+        else:
+            raise WrongInputException(
+                "Unable to parse the given URL. Try manually passing the source and the record ID."
+            )
+
+        return (source, recid)
+
     # Checks the input from the cli and raises error if there is a mistake
     def check_parameters_input(
         recid,
+        url,
         source,
         source_path,
         author,
@@ -421,6 +461,16 @@ class BasePipeline:
         a valid operation
         """
 
+        if not url and not (source and recid) and source is not "local":
+            raise WrongInputException(
+                "Source and Record ID are required if you don't provide an URL"
+            )
+
+        if url and (source or recid):
+            raise WrongInputException(
+                "You can either specify an URL or a Source and Record ID"
+            )
+
         if (bibdoc or bd_ssh_host) and (source != "cds" and source != "ilcdoc"):
             raise WrongInputException(
                 "bibdoc and bd_ssh_host parameters are only accepted when selecting CDS\
@@ -435,8 +485,6 @@ class BasePipeline:
         if recid and source == "local":
             raise WrongInputException("The local pipeline is not expecting a recid.")
 
-        if source != "local" and not recid:
-            raise WrongInputException("Recid is missing.")
         if source_path and source != "local":
             raise WrongInputException("This pipeline is not expecting a source_path.")
         if source == "local" and not author:
